// CommandLineHelper Library
// =========================
// License: Microsoft Permissive License (Ms-PL) v1.1
// Author: Rhy Mednick (http://www.rhyverse.net)
// Project Site: http://www.codeplex.com/CommandLineHelper
using System;
using System.Collections.Generic;
using System.Text;
using NUnit.Framework;
using CommandLineHelper.Attributes;

namespace CommandLineHelper.Tests
{

    [TestFixture]
    public class ValidateNotNullOrEmptyAttribute_Test
    {
        /// <summary>
        ///A test for IsValid (object)
        ///</summary>
        [Test]
        public void IsValid_ValidateNotNullOrEmptyAttribute()
        {
            ValidateNotNullOrEmptyAttribute target = new ValidateNotNullOrEmptyAttribute();

            //should not validate
            object value = null;
            bool expected = false;
            bool actual = target.IsValid(value);
            Assert.AreEqual(expected, actual, "CommandLineHelper.Attributes.ValidateNotNullOrEmptyAttribute.IsValid did not return the expected value.");

            //should not validate
            value = (object)String.Empty;
            expected = false;
            actual = target.IsValid(value);
            Assert.AreEqual(expected, actual, "CommandLineHelper.Attributes.ValidateNotNullOrEmptyAttribute.IsValid did not return the expected value.");

            //should validate because anything can be a string
            value = (object)64; //a number shouldn't validate as a string
            expected = true;
            actual = target.IsValid(value);
            Assert.AreEqual(expected, actual, "CommandLineHelper.Attributes.ValidateNotNullOrEmptyAttribute.IsValid did not return the expected value.");

            //should validate
            value = (object)new String('x', 5); //a non empty string should validate
            expected = true;
            actual = target.IsValid(value);
            Assert.AreEqual(expected, actual, "CommandLineHelper.Attributes.ValidateNotNullOrEmptyAttribute.IsValid did not return the expected value.");

        }
    }
}
